@@ -11,8 +11,8 @@ rootgrp.close()
 rootgrp = Dataset('test.nc', 'a')
 fcstgrp = rootgrp.createGroup('forecasts')
 analgrp = rootgrp.createGroup('analyses')
-fcstgrp1 = fcstgrp.createGroup('model1')
-fcstgrp2 = fcstgrp.createGroup('model2')
+fcstgrp1 = rootgrp.createGroup('/forecasts/model1')
+fcstgrp2 = rootgrp.createGroup('/forecasts/model2')
 
 # walk the group tree using a Python generator.
 def walktree(top):
@@ -23,8 +23,8 @@ def walktree(top):
             yield  children
 print(rootgrp)
 for children in walktree(rootgrp):
-     for child in children:
-         print(child)
+    for child in children:
+        print(child)
 
 # dimensions.
 level = rootgrp.createDimension('level', None)
@@ -53,6 +53,11 @@ longitudes = rootgrp.createVariable('longitude','f4',('lon',))
 # this makes the compression 'lossy' (preserving a precision of 1/1000)
 # try it and see how much smaller the file gets.
 temp = rootgrp.createVariable('temp','f4',('time','level','lat','lon',),least_significant_digit=3)
+print(temp)
+# create variable in a group using a path.
+temp = rootgrp.createVariable('/forecasts/model1/temp','f4',('time','level','lat','lon',))
+print(rootgrp['/forecasts/model1']) # print the Group instance
+print(rootgrp['/forecasts/model1/temp']) # print the Variable instance
 
 # attributes.
 import time
@@ -75,8 +80,6 @@ print(rootgrp.__dict__)
 
 print(rootgrp.variables)
 
-print(rootgrp.variables['temp'])
-
 import numpy
 # no unlimited dimension, just assign to slice.
 lats =  numpy.arange(-90,91,2.5)
@@ -201,7 +204,7 @@ data['surface_wind']['direction'] = 270
 data['temp_sounding'] = (280.3,272.,270.,269.,266.,258.,254.1,250.,245.5,240.)
 data['press_sounding'] = range(800,300,-50)
 # variable-length string datatypes are not supported inside compound types, so
-# to store strings in a compound data type, each string must be 
+# to store strings in a compound data type, each string must be
 # stored as fixed-size (in this case 80) array of characters.
 data['location_name'] = stringtoarr('Boulder, Colorado, USA',NUMCHARS)
 # assign structured array to variable slice.
