@@ -33,7 +33,6 @@ ISO8601_REGEX = re.compile(r"(?P<year>[0-9]{1,4})(-(?P<month>[0-9]{1,2})(-(?P<da
 TIMEZONE_REGEX = re.compile(
     "(?P<prefix>[+-])(?P<hours>[0-9]{1,2}):(?P<minutes>[0-9]{1,2})")
 
-
 def JulianDayFromDate(date, calendar='standard'):
     """
 
@@ -119,6 +118,13 @@ def JulianDayFromDate(date, calendar='standard'):
     # adjust for Julian calendar if necessary
     jd = jd + B
 
+    # Add a small offset (proportional to Julian date) for correct re-conversion.
+    # This is about 45 microseconds in 2000 for Julian date starting -4712.
+    # (pull request #433).
+    eps = np.finfo(float).eps
+    eps = np.maximum(eps*jd, eps)
+    jd += eps
+
     if isscalar:
         return jd[0]
     else:
@@ -232,7 +238,6 @@ def DateFromJulianDay(JD, calendar='standard'):
 
     Meeus, Jean (1998) Astronomical Algorithms (2nd Edition). Willmann-Bell,
     Virginia. p. 63
-
     """
 
     # based on redate.py by David Finlayson.
@@ -246,7 +251,7 @@ def DateFromJulianDay(JD, calendar='standard'):
     # get the day (Z) and the fraction of the day (F)
     # add 0.000005 which is 452 ms in case of jd being after
     # second 23:59:59 of a day we want to round to the next day see issue #75
-    Z = np.atleast_1d(np.int32(np.round(julian + 0.00005)))
+    Z = np.atleast_1d(np.int32(np.round(julian)))
     F = np.atleast_1d(julian + 0.5 - Z).astype(np.float64)
     if calendar in ['standard', 'gregorian']:
         # MC
@@ -313,14 +318,18 @@ def DateFromJulianDay(JD, calendar='standard'):
     inc_idx = np.where((leap == 1) & (month > 2))[0]
     dayofyr[inc_idx] = dayofyr[inc_idx] + leap[inc_idx]
 
-    eps = np.clip(
-        (1e-12 * np.abs(Z)).astype(np.float64), np.float64(1e-12), None)
-    hour = np.clip((F * 24. + eps).astype(np.int64), 0, 23)
-    F -= hour / 24.
-    minute = np.clip((F * 1440. + eps).astype(np.int64), 0, 59)
+    # Subtract the offset from JulianDayFromDate from the microseconds (pull
+    # request #433).
+    eps = np.finfo(float).eps
+    eps = np.maximum(eps*julian, eps)
+    hour = np.clip((F * 24.).astype(np.int64), 0, 23)
+    F   -= hour / 24.
+    minute = np.clip((F * 1440.).astype(np.int64), 0, 59)
+    # this is an overestimation due to added offset in JulianDayFromDate
     second = np.clip((F - minute / 1440.) * 86400., 0, None)
-    # microseconds may not be accurate.
     microsecond = (second % 1)*1.e6
+    # remove the offset from the microsecond calculation.
+    microsecond = np.clip(microsecond - eps*86400.*1e6, 0, 999999)
 
     # convert year, month, day, hour, minute, second to int32
     year = year.astype(np.int32)
@@ -1084,7 +1093,7 @@ def time2index(times, nctime, calendar=None, select='exact'):
 
         elif select == 'nearest':
             nearest_to_left = num[mismatch] < numpy.array(
-                [nctime[i - 1] + nctime[i] for i in index[mismatch]]) / 2.
+                [float(nctime[i - 1]) + float(nctime[i]) for i in index[mismatch]]) / 2.
             index[mismatch] = index[mismatch] - 1 * nearest_to_left
 
         else:
